import esbuild from "esbuild";
import copyFilePlugin from 'esbuild-plugin-copy-file';
import process from "process";
import builtins from 'builtin-modules'

const banner =
`/*
THIS IS A GENERATED/BUNDLED FILE BY ESBUILD
if you want to view the source, please visit the github repository of this plugin
*/
`;

const prod = (process.argv[2] === 'production');

esbuild.build({
	banner: {
		js: banner,
	},
	entryPoints: ['src/main.ts'],
	bundle: true,
	external: [
		'obsidian',
		'electron',
		'@codemirror/autocomplete',
		'@codemirror/closebrackets',
		'@codemirror/collab',
		'@codemirror/commands',
		'@codemirror/comment',
		'@codemirror/fold',
		'@codemirror/gutter',
		'@codemirror/highlight',
		'@codemirror/history',
		'@codemirror/language',
		'@codemirror/lint',
		'@codemirror/matchbrackets',
		'@codemirror/panel',
		'@codemirror/rangeset',
		'@codemirror/rectangular-selection',
		'@codemirror/search',
		'@codemirror/state',
		'@codemirror/stream-parser',
		'@codemirror/text',
		'@codemirror/tooltip',
		'@codemirror/view',
		...builtins],
	format: 'cjs',
	watch: !prod,
	target: 'es2016',
	logLevel: "info",
	sourcemap: prod ? false : 'inline',
	treeShaking: true,
	outfile: 'src/main.js',
	plugins: [copyFilePlugin({
		before:{},
		after: { // copy after bundling (target, source)
			// Copying to the test vault
			'./tests/Note Auto Creation Test Vault/.obsidian/plugins/obsidian-note-autocreation/styles.css': './styles.css',
			'./tests/Note Auto Creation Test Vault/.obsidian/plugins/obsidian-note-autocreation/manifest.json': './manifest.json',
			'./tests/Note Auto Creation Test Vault/.obsidian/plugins/obsidian-note-autocreation/main.js': './src/main.js',

			// Copy to release folder
			'./Release/styles.css': './styles.css',
			'./Release/manifest.json': './manifest.json',
			'./Release/main.js': './src/main.js'
		}
	})]
}).catch(() => process.exit(1));
